@@ -36,6 +36,17 @@ class RemoveAction(Action):
         super(RemoveAction, self).__init__(path)
 
 
+class ListRemoveAction(Action):
+    """
+    The List REMOVE action deletes an element from a list item based on the index.
+    """
+    format_string = None
+
+    def __init__(self, path, *indexes):
+        self.format_string = ", ".join("{{0}}[{}]".format(index) for index in indexes)
+        super(ListRemoveAction, self).__init__(path)
+
+
 class AddAction(Action):
     """
     The ADD action appends elements to a set or mathematically adds to a number attribute.
@@ -65,6 +76,7 @@ class Update(object):
         self.remove_actions = []
         self.add_actions = []
         self.delete_actions = []
+        self.list_remove_actions = []
         for action in actions:
             self.add_action(action)
 
@@ -73,6 +85,8 @@ class Update(object):
             self.set_actions.append(action)
         elif isinstance(action, RemoveAction):
             self.remove_actions.append(action)
+        elif isinstance(action, ListRemoveAction):
+            self.list_remove_actions.append(action)
         elif isinstance(action, AddAction):
             self.add_actions.append(action)
         elif isinstance(action, DeleteAction):
@@ -84,6 +98,7 @@ class Update(object):
         expression = None
         expression = self._add_clause(expression, 'SET', self.set_actions, placeholder_names, expression_attribute_values)
         expression = self._add_clause(expression, 'REMOVE', self.remove_actions, placeholder_names, expression_attribute_values)
+        expression = self._add_clause(expression, 'REMOVE', self.list_remove_actions, placeholder_names, expression_attribute_values)
         expression = self._add_clause(expression, 'ADD', self.add_actions, placeholder_names, expression_attribute_values)
         expression = self._add_clause(expression, 'DELETE', self.delete_actions, placeholder_names, expression_attribute_values)
         return expression
